@@ -126,6 +126,9 @@ def interactive_loop(
             except IndexError:
                 break
 
+            if len(command) == 0:
+                continue
+
             # Is this an alias?
             if command[0] in am.alias_names():
                 ap = AliasProcessor()
@@ -355,6 +358,10 @@ def interactive_loop(
                         print(output)
                         if len(lines) > 1 and output[len(lines) - 1] != "":
                             print()
+                    if action == "rename":
+                        speaker_name = speaker.get_speaker_info(refresh=True)[
+                            "zone_name"
+                        ]
             except:
                 print("Error: Invalid command")
 
